/*********************************************************************

 Author        : ADI - Apps            www.analog.com/MicroConverter

 Date          : May. 2007

 File          : Temperature.c

 Hardware      : Applicable to ADuC702x rev H or I silicon
                 Currently targetting ADuC7028.

 Description   : Measures and outputs internal temperature via UART at 
 				 9600bps. 
		
*********************************************************************/

#include <ADuC7028.h>

void ADCpoweron(int);

int main(void)
{  
	float a = 0;
	short b;
	
//	PLLKEY1 = 0xAA;				// switch to external crystal
//	PLLCON  = 0x01;
//	PLLKEY2 = 0x55;

	POWKEY1 = 0x01;
	POWCON = 0x00;		   			// 41.78MHz
	POWKEY2 = 0xF4;

	GP0CON = 0x010100000; 		// enable ECLK output on P0.7, and ADCbusy on P0.5
	
	GP4DAT = 0x04000000;		// P4.2 configured as an output. LED is turned on

	GP1CON = 0x011;				// Setup tx & rx pins on P1.0 and P1.1

   // Setting up UART at 9600 bps for CD = 0
	COMCON0 = 0x80;				// Setting DLAB
	COMDIV0 = 0x88;				// 
   	COMDIV1 = 0x00;
   	COMCON0 = 0x07;				// Clearing DLAB

	ADCpoweron(2000);			// power on ADC										
 	ADCCP = 0x10;				// Select Temperature Sensor as an input to the ADC
	REFCON = 0x01;				// connect internal 2.5V reference to Vref pin

	ADCCON = 0xE4;				// continuous conversion
	while(1)
	{
		GP4DAT ^= 0x00040000;		// Complement P4.2
		while (!ADCSTA){};			// wait for end of conversion

		b = (ADCDAT >> 16);			// To calculate temperature in C, use the formula:
		a = 0x525 - b;				// ((Temperature = 0x525 - Sensor Voltage) / 1.3)		
		a /= 1.3;						
						
		b = floor(a);
			
	}	
	
}



void ADCpoweron(int time)
{
	ADCCON = 0x20;	 					// power-on the ADC
	while (time >=0)	  				// wait for ADC to be fully powered on
    time--;
}
